@@ -38,8 +38,10 @@ QStringList arrLogFiles;
 void
 qgv_LogFlush()
 {
-    logCounter = 0;
-    fLogfile.flush ();
+    if (logCounter) {
+        logCounter = 0;
+        fLogfile.flush ();
+    }
 }
 
 void
@@ -80,17 +82,13 @@ myMessageOutput(QtMsgType type, const char *msg)
             fLogfile.write(strLog.toLatin1 ());
 
             ++logCounter;
-            if (logCounter > 100) {
+            if (logCounter > 50) {
                 qgv_LogFlush ();
             }
         }
     }
 
     if (NULL == pOldHandler) {
-        if (NULL == pw) {
-            fwrite (strLog.toLatin1 (), strLog.size (), 1, stderr);
-        }
-
         if (QtFatalMsg == type) {
             abort();
         }
@@ -120,8 +118,7 @@ initLogging ()
     }
 
     fLogfile.setFileName (strLogfile);
-    fLogfile.open (QIODevice::WriteOnly | QIODevice::Append);
-    fLogfile.seek (fLogfile.size ());
+    fLogfile.open (QIODevice::ReadWrite);
 
     pOldHandler = qInstallMsgHandler(myMessageOutput);
 }//initLogging
